bids.ext.reports package
========================

Module contents
---------------

.. automodule:: bids.ext.reports
   :members:
   :undoc-members:
   :show-inheritance:


Submodules
----------

bids.ext.reports.parameters module
----------------------------------

.. automodule:: bids.ext.reports.parameters
   :members:
   :undoc-members:
   :show-inheritance:

bids.ext.reports.parsing module
-------------------------------

.. automodule:: bids.ext.reports.parsing
   :members:
   :undoc-members:
   :show-inheritance:

bids.ext.reports.report module
------------------------------

.. automodule:: bids.ext.reports.report
   :members:
   :undoc-members:
   :show-inheritance:
